@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use File::Spec::Functions qw(splitdir updir catdir file_name_is_absolute);
 use Cwd qw(abs_path);
 
-our $VERSION = '0.904';
+our $VERSION = '0.905';
 
 sub register {
     my ($self, $app, $conf) = @_;
@@ -27,7 +27,7 @@ sub register {
         my $qx_app_src = abs_path(
             $ENV{QX_SRC_PATH} && file_name_is_absolute($ENV{QX_SRC_PATH})
             ? $ENV{QX_SRC_PATH} 
-            : $app->home->rel_dir($ENV{QX_SRC_PATH} || catdir(updir,'frontend','source'))
+            : $app->home->rel_file($ENV{QX_SRC_PATH} || catdir(updir,'frontend','source'))
         );
         $app->log->info("Runnning in QX_SRC_MODE with files from $qx_app_src");
         $app->static->paths([$qx_app_src]);
